{% extends 'base.html' %}

{% load ccpages_tags %}

{% block extra_css %}
		<link rel="stylesheet" href="{{STATIC_URL}}ccpages/css/ccpages.scss" media="screen" type="text/x-sass">
{% endblock %}

{% block bodyid %}ccpages{% endblock %}

