fieldset.content div input,
fieldset.other div input,
fieldset.content div textarea#id_content{
	width: 97%;
	max-width: 900px;
	padding: 10px;
	font-size: 14px;
}

fieldset.content div textarea#id_content{
	min-height: 300px;
}
div.form-row.field-parent,
div.form-row.field-status{
	border-bottom: 0 none;
	width: 45%;
	margin: 0;
	padding: 10px 10px;
	display: inline-block;
}
div.form-row.field-title{
	border-top: 1px solid #EEE;
}
	div.form-row.field-parent select,
	div.form-row.field-status select{
		width: 50%;
	}
